summaryrefslogtreecommitdiffstats
path: root/sys/kern/subr_turnstile.c
diff options
context:
space:
mode:
authorjhb <jhb@FreeBSD.org>2004-04-06 19:07:21 +0000
committerjhb <jhb@FreeBSD.org>2004-04-06 19:07:21 +0000
commit8ab84688c3dd4465acbea2186a9d970263498ea6 (patch)
treee86b2f06d6ea68eddc54e1106e60ff7bacfee1a9 /sys/kern/subr_turnstile.c
parenta048052df8fed915b18d497ad6a209a8517840d6 (diff)
downloadFreeBSD-src-8ab84688c3dd4465acbea2186a9d970263498ea6.zip
FreeBSD-src-8ab84688c3dd4465acbea2186a9d970263498ea6.tar.gz
Rename turnstile_wakeup() to turnstile_broadcast() to make the naming
more consistent with other APIs. sleepq and cv's use signal/broadcast, and msleep uses wakeup_one/wakeup. Prior to this turnstiles were using a signal/wakeup mixture.
Diffstat (limited to 'sys/kern/subr_turnstile.c')
-rw-r--r--sys/kern/subr_turnstile.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/kern/subr_turnstile.c b/sys/kern/subr_turnstile.c
index f84181d..8994a1e 100644
--- a/sys/kern/subr_turnstile.c
+++ b/sys/kern/subr_turnstile.c
@@ -234,7 +234,7 @@ propagate_priority(struct thread *td)
* finish waking this thread up. We can detect this case
* by checking to see if this thread has been given a
* turnstile by either turnstile_signal() or
* turnstile_wakeup(). In this case, treat the thread as
* if it was already running.
*/
if (td->td_turnstile != NULL) {
@@ -567,7 +567,7 @@ turnstile_signal(struct turnstile *ts)
* the turnstile chain locked.
*/
void
-turnstile_wakeup(struct turnstile *ts)
+turnstile_broadcast(struct turnstile *ts)
{
struct turnstile_chain *tc;
struct turnstile *ts1;
@@ -234,7 +234,7 @@ propagate_priority(struct thread *td)
* by checking to see if this thread has been given a
* turnstile by either turnstile_signal() or
- * turnstile_wakeup(). In this case, treat the thread as
+ * turnstile_broadcast(). In this case, treat the thread as
* if it was already running.
*/
OpenPOWER on IntegriCloud